@@ -5,7 +5,7 @@
 #       Copyright (c) 2011 R Pratap Chakravarthy
 
 """ 
-Pluggdapps, at its core, is a component architecture in python. It provides a
+Pluggdapps, at its core, is a component system in python. It provides a
 platform to specify interfaces and implement them as plugins.
 
 Plugins and interfaces can be defined in any number of packages, where
@@ -42,18 +42,21 @@ Refer to :ref:`glossary` for terminologies used.
 
 import imp, sys
 import pkg_resources    as pkg
+from   os.path          import join
 
-__version__ = '0.4dev'
+__version__ = '0.41dev'
 
 """Collect a complete list of pluggdapps packages from python
 package-environment and gather them in `papackages`."""
 pkgs = pkg.WorkingSet().by_key  # A dictionary of pkg-name and object
-papackages = { 
-    pkgname : { 'package' : d,
-                'location' : d.location
-              }
-    for pkgname, d in list( pkgs.items() ) 
-    if d.get_entry_info( 'pluggdapps', 'package' ) }
+papackages = {}
+for pkgname, d in list( pkgs.items() ) :
+    if not d.get_entry_info( 'pluggdapps', 'package' ) : continue
+    papackages.setdefault(
+        pkgname, { 'package' : d,
+                   'location' : join(d.location, d.project_name),
+                 }
+    )
 
 import pluggdapps.utils as h
 
