@@ -60,7 +60,7 @@ class it uses a special method, ``_super_init()`` instead of using the builtin
 """
 
 import sys, inspect
-from   os.path      import isfile
+from   os.path      import isfile, abspath
 
 import pluggdapps.utils as h
 
@@ -86,7 +86,7 @@ class PluginMeta( type ):
     """Plugin component manager. Tracks interface specifications, plugin
     definitions and plugins implementing interfaces. All interfaces and
     plugins defined across pluggdapps are blueprinted and handles
-    instantiation of plugins via query_plugin().
+    instantiation of plugins via one of the query_*() methods.
     Also responsibile for making plugin's configuration settings available as
     a dictionary of settings."""
 
@@ -121,7 +121,7 @@ class PluginMeta( type ):
         x = PluginMeta._interfmap.get( 
                 caname, PluginMeta._pluginmap.get( caname, None ))
         if x :
-            raise Exception( PluginMeta.err2 % (name, x['file']) )
+            raise Exception( PluginMeta.err2 % (caname, x['file']) )
 
         if Interface in mro_bases : # For Interface sub-classes
             PluginMeta._interfmap[caname] = \
@@ -287,10 +287,11 @@ def canonical_name( cls ):
     where the entire string is lower-cased. This function is to be called only
     by PluginMeta class when a plugin class is about to be blue-printed.
     """
+    # TODO : This is a hack specific to tayra template file. Make it generic.
     mod = sys.modules.get( cls.__module__ )
-    f = getattr( mod, '__file__', getattr(mod, '_ttlfile', None) )
+    f = getattr( mod, '_ttlfile', getattr(mod, '__file__', None) )
     if f and isfile(f) :
-        return (h.packagedin(f)  + '.' + cls.__name__).lower()
+        return (h.packagedin( abspath(f) )  + '.' + cls.__name__).lower()
     else :
         return cls.__name__.lower()
 
@@ -361,7 +362,9 @@ def implements( *interfaces ):
 
     if frame.f_code.co_name in core_classes : return # Skip
 
-    pkg = h.packagedin( frame.f_code.co_filename )
+    # TODO : This is a hack specific to tayra template file. Make it generic.
+    filen = frame.f_globals.get('_ttlfile', None)
+    pkg = h.packagedin( abspath(filen) if filen else frame.f_code.co_filename )
     nm = (pkg + '.' + frame.f_code.co_name).lower()
     for i in interfaces :
         if isinstance(i, str) :
@@ -380,9 +383,9 @@ class ISettings( Interface ):
     is the base class for all plugins, and provides default methods for 
     configuration settings which can later be overriden by deriving plugins.
 
-    While instantiating plugins via `query_plugin()` or `query_plugins()`
-    method, passing a ``settings`` key-word argument will override plugin's
-    settings defined by ini files and backend-store.
+    While instantiating plugins via `query_plugin()`, `query_plugins()`,
+    `query_pluginr()` methods, passing a ``settings`` key-word argument will
+    override plugin's settings defined by ini files and backend-store.
 
     All the attributes specified in this interface will automagically be
     initialised by :class:`PluginMeta`.
@@ -530,7 +533,7 @@ class Singleton( Plugin ):
 #---- Special interfaces
 
 def plugin_init():
-    """It is a chicken egg situation in pluggdapp's component architecture.
+    """It is a chicken egg situation in pluggdapp's component system.
 
     * The plugin class objects are not available until the classes are fully
       parsed and loaded.
